/* global Backbone, jQuery, _ */
var oneApp = oneApp || {};

(function (window, Backbone, $, _, oneApp) {
		'use strict';

		oneApp.views = oneApp.views || {}

		oneApp.views.item = Backbone.View.extend({
			events: {
				'click .ttfmake-media-uploader-add': 'onMediaAdd',
				'mediaSelected': 'onMediaSelected',
				'mediaRemoved': 'onMediaRemoved',
				'click .edit-content-link': 'onContentEdit',
				'change .ttfmake-configuration-overlay input[type=text]' : 'updateInputField',
				'keyup .ttfmake-configuration-overlay input[type=text]' : 'updateInputField',
				'change .ttfmake-configuration-overlay input[type=checkbox]' : 'updateCheckbox',
				'change .ttfmake-configuration-overlay select': 'updateSelectField'
			},

			updateInputField: function(e) {
				e.stopPropagation();

				var $input				= $(e.target);
				var modelAttrName = $input.attr('data-model-attr');

				if (typeof modelAttrName !== 'undefined') {
					this.model.set(modelAttrName, $input.val());
					this.$el.trigger('model-item-change');
				}
			},

			updateCheckbox: function(e) {
				e.stopPropagation();

				var $checkbox = $(e.target);
				var modelAttrName = $checkbox.attr('data-model-attr');

				if (typeof modelAttrName !== 'undefined') {
					if ($checkbox.is(':checked')) {
						this.model.set(modelAttrName, 1);
					} else {
						this.model.set(modelAttrName, 0);
					}

					this.$el.trigger('model-item-change');
				}
			},

			updateSelectField: function(e) {
				e.stopPropagation();

				var $select = $(e.target);
				var modelAttrName = $select.attr('data-model-attr');

				if (typeof modelAttrName !== 'undefined') {
					this.model.set(modelAttrName, $select.val());
					this.$el.trigger('model-item-change');
				}
			},

			onMediaAdd: function(e) {
				e.preventDefault();
				e.stopPropagation();
				oneApp.builder.initUploader(this, e.target);
			},

			onMediaSelected: function(e, attachment) {
				e.stopPropagation();
				this.model.set('image-id', attachment.id);
				this.model.set('image-url', attachment.url);
				this.$el.trigger('model-item-change');
			},

			onMediaRemoved: function(e) {
				e.stopPropagation();
				this.model.unset('image-id');
				this.model.unset('image-url');
				this.$el.trigger('model-item-change');
			},

			onContentEdit: function(e) {
				e.preventDefault();

				var $target = $(e.target);
				var iframeID = ($target.attr('data-iframe')) ? $target.attr('data-iframe') : '';
				var textAreaID = $target.attr('data-textarea');
				var $overlay = oneApp.builder.tinymceOverlay.$el;
				var $button = $('.ttfmake-overlay-close', $overlay);

				oneApp.builder.setMakeContentFromTextArea(iframeID, textAreaID);
				$button.text($button.data('original-text'));

				oneApp.builder.tinymceOverlay.open(this);
			}
		});
})(window, Backbone, jQuery, _, oneApp);